summaryrefslogtreecommitdiff
path: root/automation
diff options
context:
space:
mode:
Diffstat (limited to 'automation')
-rw-r--r--automation/taskcluster/graph/src/extend.js20
1 files changed, 17 insertions, 3 deletions
diff --git a/automation/taskcluster/graph/src/extend.js b/automation/taskcluster/graph/src/extend.js
index 633baa2ac..268daed04 100644
--- a/automation/taskcluster/graph/src/extend.js
+++ b/automation/taskcluster/graph/src/extend.js
@@ -15,9 +15,17 @@ const WINDOWS_CHECKOUT_CMD =
/*****************************************************************************/
queue.filter(task => {
- // Remove extra builds on ASan and ARM.
- if (task.collection == "asan" || task.collection == "arm-debug") {
- return task.group != "Builds";
+ if (task.group == "Builds") {
+ // Remove extra builds on ASan and ARM.
+ if (task.collection == "asan" || task.collection == "arm-debug") {
+ return false;
+ }
+
+ // Remove extra builds w/o libpkix for non-linux64-debug.
+ if (task.symbol == "noLibpkix" &&
+ (task.platform != "linux64" || task.collection != "debug")) {
+ return false;
+ }
}
return true;
@@ -184,6 +192,12 @@ async function scheduleLinux(name, base) {
symbol: "noPkcs11Bypass"
}));
+ queue.scheduleTask(merge(extra_base, {
+ name: `${name} w/ NSS_DISABLE_LIBPKIX=1`,
+ env: {NSS_DISABLE_LIBPKIX: "1"},
+ symbol: "noLibpkix"
+ }));
+
return queue.submit();
}